#
# PySNMP MIB module IANA-MAU-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IANA-MAU-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:16:01 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ConstraintsIntersection, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsIntersection", "ConstraintsUnion", "ValueSizeConstraint")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( ModuleIdentity, IpAddress, Counter64, NotificationType, Unsigned32, Integer32, Gauge32, MibIdentifier, Counter32, TimeTicks, mib_2, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "IpAddress", "Counter64", "NotificationType", "Unsigned32", "Integer32", "Gauge32", "MibIdentifier", "Counter32", "TimeTicks", "mib-2", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "ObjectIdentity")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
ianaMauMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 154)).setRevisions(("2011-08-12 00:00", "2010-02-23 00:00", "2007-04-21 00:00",))
if mibBuilder.loadTexts: ianaMauMIB.setLastUpdated('201108120000Z')
if mibBuilder.loadTexts: ianaMauMIB.setOrganization('IANA')
if mibBuilder.loadTexts: ianaMauMIB.setContactInfo('        Internet Assigned Numbers Authority\n\n                     Postal: ICANN\n                             4676 Admiralty Way, Suite 330\n                             Marina del Rey, CA 90292\n\n                        Tel: +1-310-823-9358\n                      EMail: iana&iana.org')
if mibBuilder.loadTexts: ianaMauMIB.setDescription("This MIB module defines dot3MauType OBJECT-IDENTITIES and\n         IANAifMauListBits, IANAifMauMediaAvailable,\n         IANAifMauAutoNegCapBits, and IANAifJackType\n\n         TEXTUAL-CONVENTIONs, specifying enumerated values of the\n         ifMauTypeListBits, ifMauMediaAvailable / rpMauMediaAvailable,\n         ifMauAutoNegCapabilityBits / ifMauAutoNegCapAdvertisedBits /\n         ifMauAutoNegCapReceivedBits and ifJackType / rpJackType objects\n         respectively, defined in the MAU-MIB.\n\n         It is intended that each new MAU type, Media Availability\n         state, Auto Negotiation capability and/or Jack type defined by\n         the IEEE 802.3 working group and approved for publication in a\n         revision of IEEE Std 802.3 will be added to this MIB module,\n         provided that it is suitable for being managed by the base\n         objects in the MAU-MIB.  An Expert Review, as defined in\n         RFC 2434 [RFC2434], is REQUIRED for such additions.\n\n         The following reference is used throughout this MIB module:\n\n         [IEEE802.3] refers to:\n            IEEE Std 802.3, 2005 Edition: 'IEEE Standard for\n            Information technology - Telecommunications and information\n            exchange between systems - Local and metropolitan area\n            networks - Specific requirements -\n            Part 3: Carrier sense multiple access with collision\n            detection (CSMA/CD) access method and physical layer\n            specifications'.\n\n         This reference should be updated as appropriate when new\n         MAU types, Media Availability states, Auto Negotiation\n         capabilities, and/or Jack types are added to this MIB module.\n\n         Copyright (C) The IETF Trust (2007).\n         The initial version of this MIB module was published in\n         RFC 4836; for full legal notices see the RFC itself.\n         Supplementary information may be available at:\n         http://www.ietf.org/copyrights/ianamib.html")
class IANAifMauTypeListBits(Bits, TextualConvention):
    namedValues = NamedValues(("bOther", 0), ("bAUI", 1), ("b10base5", 2), ("bFoirl", 3), ("b10base2", 4), ("b10baseT", 5), ("b10baseFP", 6), ("b10baseFB", 7), ("b10baseFL", 8), ("b10broad36", 9), ("b10baseTHD", 10), ("b10baseTFD", 11), ("b10baseFLHD", 12), ("b10baseFLFD", 13), ("b100baseT4", 14), ("b100baseTXHD", 15), ("b100baseTXFD", 16), ("b100baseFXHD", 17), ("b100baseFXFD", 18), ("b100baseT2HD", 19), ("b100baseT2FD", 20), ("b1000baseXHD", 21), ("b1000baseXFD", 22), ("b1000baseLXHD", 23), ("b1000baseLXFD", 24), ("b1000baseSXHD", 25), ("b1000baseSXFD", 26), ("b1000baseCXHD", 27), ("b1000baseCXFD", 28), ("b1000baseTHD", 29), ("b1000baseTFD", 30), ("b10GbaseX", 31), ("b10GbaseLX4", 32), ("b10GbaseR", 33), ("b10GbaseER", 34), ("b10GbaseLR", 35), ("b10GbaseSR", 36), ("b10GbaseW", 37), ("b10GbaseEW", 38), ("b10GbaseLW", 39), ("b10GbaseSW", 40), ("b10GbaseCX4", 41), ("b2BaseTL", 42), ("b10PassTS", 43), ("b100BaseBX10D", 44), ("b100BaseBX10U", 45), ("b100BaseLX10", 46), ("b1000BaseBX10D", 47), ("b1000BaseBX10U", 48), ("b1000BaseLX10", 49), ("b1000BasePX10D", 50), ("b1000BasePX10U", 51), ("b1000BasePX20D", 52), ("b1000BasePX20U", 53), ("b10GbaseT", 54), ("b10GbaseLRM", 55), ("b1000baseKX", 56), ("b10GbaseKX4", 57), ("b10GbaseKR", 58), ("b10G1GbasePRXD1", 59), ("b10G1GbasePRXD2", 60), ("b10G1GbasePRXD3", 61), ("b10G1GbasePRXU1", 62), ("b10G1GbasePRXU2", 63), ("b10G1GbasePRXU3", 64), ("b10GbasePRD1", 65), ("b10GbasePRD2", 66), ("b10GbasePRD3", 67), ("b10GbasePRU1", 68), ("b10GbasePRU3", 69), ("b40GbaseKR4", 70), ("b40GbaseCR4", 71), ("b40GbaseSR4", 72), ("b40GbaseFR", 73), ("b40GbaseLR4", 74), ("b100GbaseCR10", 75), ("b100GbaseSR10", 76), ("b100GbaseLR4", 77), ("b100GbaseER4", 78),)

class IANAifMauMediaAvailable(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("available", 3), ("notAvailable", 4), ("remoteFault", 5), ("invalidSignal", 6), ("remoteJabber", 7), ("remoteLinkLoss", 8), ("remoteTest", 9), ("offline", 10), ("autoNegError", 11), ("pmdLinkFault", 12), ("wisFrameLoss", 13), ("wisSignalLoss", 14), ("pcsLinkFault", 15), ("excessiveBER", 16), ("dxsLinkFault", 17), ("pxsLinkFault", 18), ("availableReduced", 19), ("ready", 20),)

class IANAifMauAutoNegCapBits(Bits, TextualConvention):
    namedValues = NamedValues(("bOther", 0), ("b10baseT", 1), ("b10baseTFD", 2), ("b100baseT4", 3), ("b100baseTX", 4), ("b100baseTXFD", 5), ("b100baseT2", 6), ("b100baseT2FD", 7), ("bFdxPause", 8), ("bFdxAPause", 9), ("bFdxSPause", 10), ("bFdxBPause", 11), ("b1000baseX", 12), ("b1000baseXFD", 13), ("b1000baseT", 14), ("b1000baseTFD", 15), ("b10GbaseT", 16), ("b1000baseKX", 17), ("b10GbaseKX4", 18), ("b10GbaseKR", 19), ("b40GbaseKR4", 20), ("b40GbaseCR4", 21), ("b100GbaseCR10", 22),)

class IANAifJackType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,))
    namedValues = NamedValues(("other", 1), ("rj45", 2), ("rj45S", 3), ("db9", 4), ("bnc", 5), ("fAUI", 6), ("mAUI", 7), ("fiberSC", 8), ("fiberMIC", 9), ("fiberST", 10), ("telco", 11), ("mtrj", 12), ("hssdc", 13), ("fiberLC", 14), ("cx4", 15),)

dot3MauType = MibIdentifier((1, 3, 6, 1, 2, 1, 26, 4))
dot3MauTypeAUI = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 1))
if mibBuilder.loadTexts: dot3MauTypeAUI.setDescription('no internal MAU, view from AUI')
dot3MauType10Base5 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 2))
if mibBuilder.loadTexts: dot3MauType10Base5.setDescription('thick coax MAU')
dot3MauTypeFoirl = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 3))
if mibBuilder.loadTexts: dot3MauTypeFoirl.setDescription('FOIRL MAU')
dot3MauType10Base2 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 4))
if mibBuilder.loadTexts: dot3MauType10Base2.setDescription('thin coax MAU')
dot3MauType10BaseT = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 5))
if mibBuilder.loadTexts: dot3MauType10BaseT.setDescription('UTP MAU.\n                   Note that it is strongly recommended that\n                   agents return either dot3MauType10BaseTHD or\n                   dot3MauType10BaseTFD if the duplex mode is\n                   known.  However, management applications should\n                   be prepared to receive this MAU type value from\n                   older agent implementations.')
dot3MauType10BaseFP = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 6))
if mibBuilder.loadTexts: dot3MauType10BaseFP.setDescription('passive fiber MAU')
dot3MauType10BaseFB = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 7))
if mibBuilder.loadTexts: dot3MauType10BaseFB.setDescription('sync fiber MAU')
dot3MauType10BaseFL = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 8))
if mibBuilder.loadTexts: dot3MauType10BaseFL.setDescription('async fiber MAU.\n                   Note that it is strongly recommended that\n                   agents return either dot3MauType10BaseFLHD or\n                   dot3MauType10BaseFLFD if the duplex mode is\n                   known.  However, management applications should\n                   be prepared to receive this MAU type value from\n                   older agent implementations.')
dot3MauType10Broad36 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 9))
if mibBuilder.loadTexts: dot3MauType10Broad36.setDescription('broadband DTE MAU.\n                   Note that 10BROAD36 MAUs can be attached to\n                   interfaces but not to repeaters.')
dot3MauType10BaseTHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 10))
if mibBuilder.loadTexts: dot3MauType10BaseTHD.setDescription('UTP MAU, half duplex mode')
dot3MauType10BaseTFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 11))
if mibBuilder.loadTexts: dot3MauType10BaseTFD.setDescription('UTP MAU, full duplex mode')
dot3MauType10BaseFLHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 12))
if mibBuilder.loadTexts: dot3MauType10BaseFLHD.setDescription('async fiber MAU, half duplex mode')
dot3MauType10BaseFLFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 13))
if mibBuilder.loadTexts: dot3MauType10BaseFLFD.setDescription('async fiber MAU, full duplex mode')
dot3MauType100BaseT4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 14))
if mibBuilder.loadTexts: dot3MauType100BaseT4.setDescription('4 pair category 3 UTP')
dot3MauType100BaseTXHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 15))
if mibBuilder.loadTexts: dot3MauType100BaseTXHD.setDescription('2 pair category 5 UTP, half duplex mode')
dot3MauType100BaseTXFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 16))
if mibBuilder.loadTexts: dot3MauType100BaseTXFD.setDescription('2 pair category 5 UTP, full duplex mode')
dot3MauType100BaseFXHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 17))
if mibBuilder.loadTexts: dot3MauType100BaseFXHD.setDescription('X fiber over PMT, half duplex mode')
dot3MauType100BaseFXFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 18))
if mibBuilder.loadTexts: dot3MauType100BaseFXFD.setDescription('X fiber over PMT, full duplex mode')
dot3MauType100BaseT2HD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 19))
if mibBuilder.loadTexts: dot3MauType100BaseT2HD.setDescription('2 pair category 3 UTP, half duplex mode')
dot3MauType100BaseT2FD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 20))
if mibBuilder.loadTexts: dot3MauType100BaseT2FD.setDescription('2 pair category 3 UTP, full duplex mode')
dot3MauType1000BaseXHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 21))
if mibBuilder.loadTexts: dot3MauType1000BaseXHD.setDescription('PCS/PMA, unknown PMD, half duplex mode')
dot3MauType1000BaseXFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 22))
if mibBuilder.loadTexts: dot3MauType1000BaseXFD.setDescription('PCS/PMA, unknown PMD, full duplex mode')
dot3MauType1000BaseLXHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 23))
if mibBuilder.loadTexts: dot3MauType1000BaseLXHD.setDescription('Fiber over long-wavelength laser, half duplex\n                   mode')
dot3MauType1000BaseLXFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 24))
if mibBuilder.loadTexts: dot3MauType1000BaseLXFD.setDescription('Fiber over long-wavelength laser, full duplex\n                   mode')
dot3MauType1000BaseSXHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 25))
if mibBuilder.loadTexts: dot3MauType1000BaseSXHD.setDescription('Fiber over short-wavelength laser, half\n                   duplex mode')
dot3MauType1000BaseSXFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 26))
if mibBuilder.loadTexts: dot3MauType1000BaseSXFD.setDescription('Fiber over short-wavelength laser, full\n                   duplex mode')
dot3MauType1000BaseCXHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 27))
if mibBuilder.loadTexts: dot3MauType1000BaseCXHD.setDescription('Copper over 150-Ohm balanced cable, half\n                   duplex mode')
dot3MauType1000BaseCXFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 28))
if mibBuilder.loadTexts: dot3MauType1000BaseCXFD.setDescription('Copper over 150-Ohm balanced cable, full\n\n                   duplex mode')
dot3MauType1000BaseTHD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 29))
if mibBuilder.loadTexts: dot3MauType1000BaseTHD.setDescription('Four-pair Category 5 UTP, half duplex mode')
dot3MauType1000BaseTFD = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 30))
if mibBuilder.loadTexts: dot3MauType1000BaseTFD.setDescription('Four-pair Category 5 UTP, full duplex mode')
dot3MauType10GigBaseX = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 31))
if mibBuilder.loadTexts: dot3MauType10GigBaseX.setDescription('X PCS/PMA, unknown PMD.')
dot3MauType10GigBaseLX4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 32))
if mibBuilder.loadTexts: dot3MauType10GigBaseLX4.setDescription('X fiber over WWDM optics')
dot3MauType10GigBaseR = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 33))
if mibBuilder.loadTexts: dot3MauType10GigBaseR.setDescription('R PCS/PMA, unknown PMD.')
dot3MauType10GigBaseER = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 34))
if mibBuilder.loadTexts: dot3MauType10GigBaseER.setDescription('R fiber over 1550 nm optics')
dot3MauType10GigBaseLR = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 35))
if mibBuilder.loadTexts: dot3MauType10GigBaseLR.setDescription('R fiber over 1310 nm optics')
dot3MauType10GigBaseSR = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 36))
if mibBuilder.loadTexts: dot3MauType10GigBaseSR.setDescription('R fiber over 850 nm optics')
dot3MauType10GigBaseW = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 37))
if mibBuilder.loadTexts: dot3MauType10GigBaseW.setDescription('W PCS/PMA, unknown PMD.')
dot3MauType10GigBaseEW = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 38))
if mibBuilder.loadTexts: dot3MauType10GigBaseEW.setDescription('W fiber over 1550 nm optics')
dot3MauType10GigBaseLW = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 39))
if mibBuilder.loadTexts: dot3MauType10GigBaseLW.setDescription('W fiber over 1310 nm optics')
dot3MauType10GigBaseSW = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 40))
if mibBuilder.loadTexts: dot3MauType10GigBaseSW.setDescription('W fiber over 850 nm optics')
dot3MauType10GigBaseCX4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 41))
if mibBuilder.loadTexts: dot3MauType10GigBaseCX4.setDescription('X copper over 8 pair 100-Ohm balanced cable')
dot3MauType2BaseTL = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 42))
if mibBuilder.loadTexts: dot3MauType2BaseTL.setDescription('Voice grade UTP copper, up to 2700m, optional PAF')
dot3MauType10PassTS = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 43))
if mibBuilder.loadTexts: dot3MauType10PassTS.setDescription('Voice grade UTP copper, up to 750m, optional PAF')
dot3MauType100BaseBX10D = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 44))
if mibBuilder.loadTexts: dot3MauType100BaseBX10D.setDescription('One single-mode fiber OLT, long wavelength, 10km')
dot3MauType100BaseBX10U = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 45))
if mibBuilder.loadTexts: dot3MauType100BaseBX10U.setDescription('One single-mode fiber ONU, long wavelength, 10km')
dot3MauType100BaseLX10 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 46))
if mibBuilder.loadTexts: dot3MauType100BaseLX10.setDescription('Two single-mode fibers, long wavelength, 10km')
dot3MauType1000BaseBX10D = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 47))
if mibBuilder.loadTexts: dot3MauType1000BaseBX10D.setDescription('One single-mode fiber OLT, long wavelength, 10km')
dot3MauType1000BaseBX10U = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 48))
if mibBuilder.loadTexts: dot3MauType1000BaseBX10U.setDescription('One single-mode fiber ONU, long wavelength, 10km')
dot3MauType1000BaseLX10 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 49))
if mibBuilder.loadTexts: dot3MauType1000BaseLX10.setDescription('Two sigle-mode fiber, long wavelength, 10km')
dot3MauType1000BasePX10D = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 50))
if mibBuilder.loadTexts: dot3MauType1000BasePX10D.setDescription('One single-mode fiber EPON OLT, 10km')
dot3MauType1000BasePX10U = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 51))
if mibBuilder.loadTexts: dot3MauType1000BasePX10U.setDescription('One single-mode fiber EPON ONU, 10km')
dot3MauType1000BasePX20D = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 52))
if mibBuilder.loadTexts: dot3MauType1000BasePX20D.setDescription('One single-mode fiber EPON OLT, 20km')
dot3MauType1000BasePX20U = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 53))
if mibBuilder.loadTexts: dot3MauType1000BasePX20U.setDescription('One single-mode fiber EPON ONU, 20km')
dot3MauType10GbaseT = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 54))
if mibBuilder.loadTexts: dot3MauType10GbaseT.setDescription('Four-pair Category 6A or better, full duplex mode only')
dot3MauType10GbaseLRM = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 55))
if mibBuilder.loadTexts: dot3MauType10GbaseLRM.setDescription('R multimode fiber over 1310 nm optics')
dot3MauType1000baseKX = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 56))
if mibBuilder.loadTexts: dot3MauType1000baseKX.setDescription('X backplane, full duplex mode only')
dot3MauType10GbaseKX4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 57))
if mibBuilder.loadTexts: dot3MauType10GbaseKX4.setDescription('4 lane X backplane, full duplex mode only')
dot3MauType10GbaseKR = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 58))
if mibBuilder.loadTexts: dot3MauType10GbaseKR.setDescription('R backplane, full duplex mode only')
dot3MauType10G1GbasePRXD1 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 59))
if mibBuilder.loadTexts: dot3MauType10G1GbasePRXD1.setDescription('One single-mode fiber asymmetric-rate EPON OLT, supporting low\n                    power budget (PRX10)')
dot3MauType10G1GbasePRXD2 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 60))
if mibBuilder.loadTexts: dot3MauType10G1GbasePRXD2.setDescription('One single-mode fiber asymmetric-rate EPON OLT, supporting\n                   medium power budget (PRX20)')
dot3MauType10G1GbasePRXD3 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 61))
if mibBuilder.loadTexts: dot3MauType10G1GbasePRXD3.setDescription('One single-mode fiber asymmetric-rate EPON OLT, supporting high\n                   power budget (PRX30)')
dot3MauType10G1GbasePRXU1 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 62))
if mibBuilder.loadTexts: dot3MauType10G1GbasePRXU1.setDescription('One single-mode fiber asymmetric-rate EPON ONU, supporting low\n                   power budget (PRX10)')
dot3MauType10G1GbasePRXU2 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 63))
if mibBuilder.loadTexts: dot3MauType10G1GbasePRXU2.setDescription('One single-mode fiber asymmetric-rate EPON ONU, supporting\n                   medium power budget (PRX20)')
dot3MauType10G1GbasePRXU3 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 64))
if mibBuilder.loadTexts: dot3MauType10G1GbasePRXU3.setDescription('One single-mode fiber asymmetric-rate EPON ONU, supporting high\n                   power budget (PRX30)')
dot3MauType10GbasePRD1 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 65))
if mibBuilder.loadTexts: dot3MauType10GbasePRD1.setDescription('One single-mode fiber symmetric-rate EPON OLT, supporting low\n                   power budget (PR10)')
dot3MauType10GbasePRD2 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 66))
if mibBuilder.loadTexts: dot3MauType10GbasePRD2.setDescription('One single-mode fiber symmetric-rate EPON OLT, supporting\n                   medium power budget (PR20)')
dot3MauType10GbasePRD3 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 67))
if mibBuilder.loadTexts: dot3MauType10GbasePRD3.setDescription('One single-mode fiber symmetric-rate EPON OLT, supporting high\n                   power budget (PR30)')
dot3MauType10GbasePRU1 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 68))
if mibBuilder.loadTexts: dot3MauType10GbasePRU1.setDescription('One single-mode fiber symmetric-rate EPON ONU, supporting\n                   low and medium power budget (PR10 and PR20)')
dot3MauType10GbasePRU3 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 69))
if mibBuilder.loadTexts: dot3MauType10GbasePRU3.setDescription('One single-mode fiber symmetric-rate EPON ONU, supporting high\n                   power budget (PR30)')
dot3MauType40GbaseKR4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 70))
if mibBuilder.loadTexts: dot3MauType40GbaseKR4.setDescription('40GBASE-R PCS/PMA over an electrical \n                      backplane')
dot3MauType40GbaseCR4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 71))
if mibBuilder.loadTexts: dot3MauType40GbaseCR4.setDescription('40GBASE-R PCS/PMA over 4 lane shielded \n                      copper balanced cable')
dot3MauType40GbaseSR4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 72))
if mibBuilder.loadTexts: dot3MauType40GbaseSR4.setDescription('40GBASE-R PCS/PMA over 4 lane multimode \n                      fiber')
dot3MauType40GbaseFR = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 73))
if mibBuilder.loadTexts: dot3MauType40GbaseFR.setDescription('40GBASE-R PCS/PMA over single mode \n                      fiber')
dot3MauType40GbaseLR4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 74))
if mibBuilder.loadTexts: dot3MauType40GbaseLR4.setDescription('40GBASE-R PCS/PMA over 4 WDM lane \n                      single mode fiber')
dot3MauType100GbaseCR10 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 75))
if mibBuilder.loadTexts: dot3MauType100GbaseCR10.setDescription('100GBASE-R PCS/PMA over 10 lane \n                      shielded copper balanced cable')
dot3MauType100GbaseSR10 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 76))
if mibBuilder.loadTexts: dot3MauType100GbaseSR10.setDescription('100GBASE-R PCS/PMA over 10 lane \n                      multimode fiber')
dot3MauType100GbaseLR4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 77))
if mibBuilder.loadTexts: dot3MauType100GbaseLR4.setDescription('100GBASE-R PCS/PMA over 4 WDM lane \n                      single mode fiber, long reach')
dot3MauType100GbaseER4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 26, 4, 78))
if mibBuilder.loadTexts: dot3MauType100GbaseER4.setDescription('100GBASE-R PCS/PMA over 4 WDM lane \n                      single mode fiber PMD, extended reach')
mibBuilder.exportSymbols("IANA-MAU-MIB", dot3MauType10BaseFP=dot3MauType10BaseFP, dot3MauType1000BaseSXHD=dot3MauType1000BaseSXHD, dot3MauType10G1GbasePRXD1=dot3MauType10G1GbasePRXD1, IANAifMauMediaAvailable=IANAifMauMediaAvailable, dot3MauType10BaseFLFD=dot3MauType10BaseFLFD, dot3MauType10GigBaseX=dot3MauType10GigBaseX, dot3MauType10GigBaseW=dot3MauType10GigBaseW, dot3MauType10GigBaseCX4=dot3MauType10GigBaseCX4, dot3MauType1000BaseLX10=dot3MauType1000BaseLX10, dot3MauType1000BaseXHD=dot3MauType1000BaseXHD, dot3MauType1000BasePX20D=dot3MauType1000BasePX20D, dot3MauType10GigBaseLR=dot3MauType10GigBaseLR, dot3MauType10GigBaseLX4=dot3MauType10GigBaseLX4, dot3MauType2BaseTL=dot3MauType2BaseTL, dot3MauType10GbaseKR=dot3MauType10GbaseKR, dot3MauType10GigBaseSW=dot3MauType10GigBaseSW, dot3MauType1000BaseBX10U=dot3MauType1000BaseBX10U, PYSNMP_MODULE_ID=ianaMauMIB, dot3MauType100GbaseER4=dot3MauType100GbaseER4, dot3MauType40GbaseCR4=dot3MauType40GbaseCR4, dot3MauType10GbasePRU1=dot3MauType10GbasePRU1, dot3MauType100BaseBX10D=dot3MauType100BaseBX10D, dot3MauType1000BasePX10U=dot3MauType1000BasePX10U, dot3MauType10BaseFB=dot3MauType10BaseFB, dot3MauType10GigBaseLW=dot3MauType10GigBaseLW, dot3MauType=dot3MauType, dot3MauType100GbaseSR10=dot3MauType100GbaseSR10, dot3MauType100GbaseLR4=dot3MauType100GbaseLR4, IANAifMauAutoNegCapBits=IANAifMauAutoNegCapBits, dot3MauType1000BaseXFD=dot3MauType1000BaseXFD, dot3MauType1000BasePX10D=dot3MauType1000BasePX10D, ianaMauMIB=ianaMauMIB, dot3MauType10Broad36=dot3MauType10Broad36, dot3MauType40GbaseFR=dot3MauType40GbaseFR, dot3MauType10GbasePRD3=dot3MauType10GbasePRD3, dot3MauType100BaseTXHD=dot3MauType100BaseTXHD, dot3MauType10BaseFLHD=dot3MauType10BaseFLHD, dot3MauType10BaseFL=dot3MauType10BaseFL, dot3MauType100BaseFXHD=dot3MauType100BaseFXHD, dot3MauType1000BaseBX10D=dot3MauType1000BaseBX10D, dot3MauType10GigBaseER=dot3MauType10GigBaseER, dot3MauType1000BasePX20U=dot3MauType1000BasePX20U, dot3MauType10Base2=dot3MauType10Base2, dot3MauType10GbaseT=dot3MauType10GbaseT, dot3MauType10G1GbasePRXU1=dot3MauType10G1GbasePRXU1, dot3MauType10GbasePRD2=dot3MauType10GbasePRD2, IANAifMauTypeListBits=IANAifMauTypeListBits, dot3MauType1000BaseTFD=dot3MauType1000BaseTFD, dot3MauType10PassTS=dot3MauType10PassTS, dot3MauType40GbaseKR4=dot3MauType40GbaseKR4, IANAifJackType=IANAifJackType, dot3MauType10GbaseLRM=dot3MauType10GbaseLRM, dot3MauType10Base5=dot3MauType10Base5, dot3MauType100BaseLX10=dot3MauType100BaseLX10, dot3MauType10GigBaseR=dot3MauType10GigBaseR, dot3MauType100BaseT2FD=dot3MauType100BaseT2FD, dot3MauType100GbaseCR10=dot3MauType100GbaseCR10, dot3MauType1000BaseCXHD=dot3MauType1000BaseCXHD, dot3MauType10GigBaseSR=dot3MauType10GigBaseSR, dot3MauType10G1GbasePRXU2=dot3MauType10G1GbasePRXU2, dot3MauType10BaseT=dot3MauType10BaseT, dot3MauType10GigBaseEW=dot3MauType10GigBaseEW, dot3MauType10BaseTFD=dot3MauType10BaseTFD, dot3MauType100BaseT4=dot3MauType100BaseT4, dot3MauType100BaseFXFD=dot3MauType100BaseFXFD, dot3MauType1000BaseCXFD=dot3MauType1000BaseCXFD, dot3MauType10GbasePRD1=dot3MauType10GbasePRD1, dot3MauType40GbaseLR4=dot3MauType40GbaseLR4, dot3MauType1000BaseLXHD=dot3MauType1000BaseLXHD, dot3MauType40GbaseSR4=dot3MauType40GbaseSR4, dot3MauType1000BaseLXFD=dot3MauType1000BaseLXFD, dot3MauTypeFoirl=dot3MauTypeFoirl, dot3MauType10BaseTHD=dot3MauType10BaseTHD, dot3MauType100BaseT2HD=dot3MauType100BaseT2HD, dot3MauType1000BaseSXFD=dot3MauType1000BaseSXFD, dot3MauType10G1GbasePRXD3=dot3MauType10G1GbasePRXD3, dot3MauType100BaseBX10U=dot3MauType100BaseBX10U, dot3MauType10GbaseKX4=dot3MauType10GbaseKX4, dot3MauType10G1GbasePRXD2=dot3MauType10G1GbasePRXD2, dot3MauType1000baseKX=dot3MauType1000baseKX, dot3MauType10G1GbasePRXU3=dot3MauType10G1GbasePRXU3, dot3MauTypeAUI=dot3MauTypeAUI, dot3MauType10GbasePRU3=dot3MauType10GbasePRU3, dot3MauType100BaseTXFD=dot3MauType100BaseTXFD, dot3MauType1000BaseTHD=dot3MauType1000BaseTHD)



#
# PySNMP MIB module SSPM-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SSPM-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:29:28 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( AppLocalIndex, ) = mibBuilder.importSymbols("APM-MIB", "AppLocalIndex")
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion")
( InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero")
( InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
( OwnerString, rmon, ) = mibBuilder.importSymbols("RMON-MIB", "OwnerString", "rmon")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Counter32, ModuleIdentity, Counter64, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, IpAddress, Integer32, NotificationType, iso, Gauge32, Bits, ObjectIdentity, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "ModuleIdentity", "Counter64", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "IpAddress", "Integer32", "NotificationType", "iso", "Gauge32", "Bits", "ObjectIdentity", "MibIdentifier")
( StorageType, TextualConvention, RowStatus, DisplayString, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "TextualConvention", "RowStatus", "DisplayString", "TruthValue")
( Utf8String, ) = mibBuilder.importSymbols("SYSAPPL-MIB", "Utf8String")
sspmMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 16, 28)).setRevisions(("2005-07-28 00:00",))
if mibBuilder.loadTexts: sspmMIB.setLastUpdated('200507280000Z')
if mibBuilder.loadTexts: sspmMIB.setOrganization('IETF RMON MIB working group')
if mibBuilder.loadTexts: sspmMIB.setContactInfo('        Carl W. Kalbfleisch\n                    Consultant\n\n            E-mail: ietf@kalbfleisch.us\n\n            Working group mailing list: rmonmib@ietf.org\n            To subscribe send email to rmonmib-request@ietf.org')
if mibBuilder.loadTexts: sspmMIB.setDescription('This SSPM MIB module is applicable to probes\n            implementing Synthetic Source for Performance\n            Monitoring functions.\n\n            Copyright (C) The Internet Society (2005).  This version\n            of this MIB module is part of RFC 4149; see the RFC\n            itself for full legal notices.')
sspmMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 28, 1))
sspmMIBNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 28, 2))
sspmMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 28, 3))
class SspmMicroSeconds(Unsigned32, TextualConvention):
    displayHint = 'd'

class SspmClockSource(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,255)

class SspmClockMaxSkew(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,65535)

sspmGeneral = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 28, 1, 1))
sspmGeneralClockResolution = MibScalar((1, 3, 6, 1, 2, 1, 16, 28, 1, 1, 1), SspmMicroSeconds()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sspmGeneralClockResolution.setDescription('A read-only variable indicating the resolution\n      of the measurements possible by this device.')
sspmGeneralClockMaxSkew = MibScalar((1, 3, 6, 1, 2, 1, 16, 28, 1, 1, 2), SspmClockMaxSkew()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sspmGeneralClockMaxSkew.setDescription('A read-only variable indicating the maximum offset\n         error due to skew of the local clock over the\n         time interval 86400 seconds, in seconds.')
sspmGeneralClockSource = MibScalar((1, 3, 6, 1, 2, 1, 16, 28, 1, 1, 3), SspmClockSource()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sspmGeneralClockSource.setDescription('A read-only variable indicating the source of the clock.\n         This is provided to allow a user to determine how accurate\n         the timing mechanism is compared with other devices.  This\n         is needed for the coordination of time values\n         between probes for one-way measurements.')
sspmGeneralMinFrequency = MibScalar((1, 3, 6, 1, 2, 1, 16, 28, 1, 1, 4), SspmMicroSeconds()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sspmGeneralMinFrequency.setDescription("A read-only variable that indicates the devices'\n          capability for the minimum supported\n          sspmSourceFrequency.  If sspmSourceFrequency is\n          set to a value lower than the value reported\n          by this attribute, then the set of sspmSourceFrequency\n          will fail with an inconsistent value error.")
sspmCapabilitiesTable = MibTable((1, 3, 6, 1, 2, 1, 16, 28, 1, 1, 5), )
if mibBuilder.loadTexts: sspmCapabilitiesTable.setDescription('The table of SSPM capabilities.')
sspmCapabilitiesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 28, 1, 1, 5, 1), ).setIndexNames((0, "SSPM-MIB", "sspmCapabilitiesInstance"))
if mibBuilder.loadTexts: sspmCapabilitiesEntry.setDescription('Details about a particular SSPM capability.')
sspmCapabilitiesInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 1, 5, 1, 1), AppLocalIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sspmCapabilitiesInstance.setDescription('Indicates whether SSPM configuration of the corresponding\n         AppLocalIndex is supported by this device.  Generally,\n         entries in this table are only made by the device when the\n         configuration of the measurement is available.')
sspmSource = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 28, 1, 2))
sspmSourceProfileTable = MibTable((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1), )
if mibBuilder.loadTexts: sspmSourceProfileTable.setDescription('The table of SSPM Source Profiles configured.')
sspmSourceProfileEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1), ).setIndexNames((0, "SSPM-MIB", "sspmSourceProfileInstance"))
if mibBuilder.loadTexts: sspmSourceProfileEntry.setDescription('Details about a particular SSPM Source Profile\n         configuration.  Entries must exist in this table\n         in order to be referenced by rows in the\n         sspmSourceControlTable.')
sspmSourceProfileInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: sspmSourceProfileInstance.setDescription('An arbitrary index.')
sspmSourceProfileType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 2), AppLocalIndex()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileType.setDescription("The AppLocalIndex value that uniquely identifies the\n         measurement per the APM-MIB.  In order to create a row\n         in this table, there must be a corresponding row in the\n         sspmCapabilitiesTable.\n\n         When attempting to set this object, if no\n         corresponding row exists in the sspmCapabilitiesTable,\n         then the agent should return a 'badValue' error.")
sspmSourceProfilePacketSize = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 3), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfilePacketSize.setDescription("The size of packet to be transmitted in bytes.  The\n         size accounts for all data within the IPv4 or IPv6\n         payloads, excluding the IP headers, IP header options\n         and link-level protocol headers.\n\n         If the size is set smaller than the minimum allowed\n         packet size or greater than the maximum allowed\n         packet size, then the set should fail, and the agent\n         should return a 'badValue' error.")
sspmSourceProfilePacketFillType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("random", 1), ("pattern", 2), ("url", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfilePacketFillType.setDescription("Indicates how the packet is filled.\n\n         'random' indicates that the packet contains random\n         data patterns.  This is probe and implementation\n         dependent.\n\n         'pattern' indicates that the pattern defined in the\n         sspmSourceProfilePacketFillValue attribute is used to\n         fill the packet.\n\n         'url' indicates that the value of\n         sspmSourceProfilePacketFillValue should\n         contain a URL.  The contents of the document\n         at that URL are retrieved when sspmSourceStatus becomes\n         active and utilized in the packet.  If the attempt to\n         access that URL fails, then the row status is set to\n         'notReady', and the set should fail with\n         'inconsistentValue'.  This value must contain a\n         dereferencable URL of the type 'http:', 'https:', or\n         'ftp:' only.")
sspmSourceProfilePacketFillValue = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfilePacketFillValue.setDescription("The string value with which to fill the packet.  If\n         sspmSourceProfilePacketFillType is set to 'pattern',\n         then this pattern is repeated until the packet is\n         sspmSourcePacketSize in bytes.  Note that if the\n         length of the octet string specified for this\n         value does not divide evenly into the packet\n         size, then an incomplete last copy of this data\n         may be copied into the packet.  If the value of\n         sspmSourceProfilePacketFillType is set to 'random', then\n         this attribute is unused.  If the value of the\n         sspmSourceProfilePacketFillType is set to 'url', then\n         the URL specified in this attribute is retrieved\n         and used by the probe.  In the case of a URL, this value\n         must contain a dereferencable URL of the type\n         'http:', 'https:', or 'ftp:' only.")
sspmSourceProfileTOS = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileTOS.setDescription('Represents the TOS field in the IP packet header.  The\n        value of this object defaults to zero if not set.')
sspmSourceProfileFlowLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,1048575))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileFlowLabel.setDescription('This object is used to specify the Flow Label in a IPv6\n         packet (RFC 2460) to force special handling by the IPv6\n         routers; e.g., non-default quality-of-service handling.\n\n         This object is meaningful only when the object\n         sspmSourceDestAddressType is IPv6(2).\n         The value of this object defaults to zero if not set.')
sspmSourceProfileLooseSrcRteFill = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 8), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,240))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileLooseSrcRteFill.setDescription('In the event that the test should run over a\n         specific route, the intent is to force the route using the\n         Loose Source Route option in IPv4 [RFC791] and\n         IPv6 [RFC2460].  This object contains a\n         series of IP addresses along the path that would be\n         put into the loose source route option in the IP header.\n\n         The IPv4 addresses are to be listed as 32-bit\n         address values, and the IPv6 addresses are to be\n         listed as a string of 128-bit addresses.  The\n         maximum length allowed within the IPv4 source route\n         option is 63 addresses.  To simply account for\n         IPv6 addresses as well, the maximum length of the\n         octet string is 240.  This allows up to 60\n         IPv4 addresses or up to 15 IPv6 addresses in the\n         string.')
sspmSourceProfileLooseSrcRteLen = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,240))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileLooseSrcRteLen.setDescription('In the event that the test should run over a\n         specific route, the intent is to force the route.\n         This attribute specifies the length of data to\n         be copied from the sspmSourceProfileLooseSrcRteFill\n         into the route data fields of the loose source route\n\n         options in the IPv4 or IPv6 headers.')
sspmSourceProfileTTL = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileTTL.setDescription('If non-zero, this specifies the value to place into\n         the TTL field on transmission.')
sspmSourceProfileNoFrag = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 11), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileNoFrag.setDescription("When true, the 'Don't Fragment Bit' should be set\n         on the packet header.")
sspmSourceProfile8021Tagging = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-1,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfile8021Tagging.setDescription("IEEE 802.1Q tagging used in IEEE 802.1D bridged\n        environments.\n\n        A value of -1 indicates that the packets are untagged.\n\n        A value of 0 to 65535 is the value of the tag to be\n        inserted in the tagged packets.\n\n        Note that according to IEEE 802.1Q, VLAN-ID tags with\n        a value of 4095 shall not be transmitted on the wire.\n        As the VLAN-ID is encoded in the 12 least significant\n        bits on the tag, values that translate in a binary\n        representation of all 1's in the last 12 bits\n        SHALL NOT be configured.  In this case, the set should\n        fail, and return an error-status of 'inconsistentValue'.")
sspmSourceProfileUsername = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 13), Utf8String()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileUsername.setDescription('An optional username used by the application protocol.')
sspmSourceProfilePassword = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 14), Utf8String()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfilePassword.setDescription('An optional password used by the application protocol.')
sspmSourceProfileParameter = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 15), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileParameter.setDescription('An optional parameter used by the application protocol.\n         For DNS, this would be the hostname or IP.  For HTTP,\n         this would be the URL.  For nntp, this would be the\n         news group.  For TCP, this would be the port number.\n         For SMTP, this would be the recipient (and could\n         assume the message is predefined).')
sspmSourceProfileOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 16), OwnerString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileOwner.setDescription('Name of the management station/application that\n        set up the profile.')
sspmSourceProfileStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 17), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileStorageType.setDescription("The storage type of this sspmSourceProfileEntry.  If the\n        value of this object is 'permanent', no objects in this row\n        need to be writable.")
sspmSourceProfileStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 1, 1, 18), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceProfileStatus.setDescription('Status of this profile.\n\n        An entry may not exist in the active state unless all\n        objects in the entry have an appropriate value.\n\n        Once this object is set to active(1), no objects in the\n        sspmSourceProfileTable can be changed.')
sspmSourceControlTable = MibTable((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2), )
if mibBuilder.loadTexts: sspmSourceControlTable.setDescription('The table of SSPM measurements configured.')
sspmSourceControlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1), ).setIndexNames((0, "SSPM-MIB", "sspmSourceControlInstance"))
if mibBuilder.loadTexts: sspmSourceControlEntry.setDescription('Details about a particular SSPM configuration.')
sspmSourceControlInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: sspmSourceControlInstance.setDescription('An arbitrary index.')
sspmSourceControlProfile = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlProfile.setDescription('A pointer to the profile (sspmSourceProfileEntry) that\n         this control entry uses to define the test being\n         performed.')
sspmSourceControlSrc = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 3), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlSrc.setDescription('The ifIndex where the packet should originate from the\n         probe (if it matters).  A value of zero indicates that\n         it does not matter and that the device decides.')
sspmSourceControlDestAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 4), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlDestAddrType.setDescription('The type of Internet address by which the destination\n         is accessed.')
sspmSourceControlDestAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 5), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlDestAddr.setDescription('The Internet address for the destination.  The formatting\n        of this object is controlled by the\n        sspmSourceControlDestAddrType object above.\n\n        When this object contains a DNS name, then the name is\n        resolved to an address each time measurement is to be made.\n        Further, the agent should not cache this address,\n        but instead should perform the resolution prior to each\n        measurement.')
sspmSourceControlEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 6), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlEnabled.setDescription("When set to 'true', this test is enabled.  When set to\n         'false', it is disabled.")
sspmSourceControlTimeOut = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 7), SspmMicroSeconds()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlTimeOut.setDescription('Timeout value for the measurement response.  If no\n         response is received in the time specified, then\n         the test fails.')
sspmSourceControlSamplingDist = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("deterministic", 1), ("poisson", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlSamplingDist.setDescription("When this attribute is set to 'deterministic', then\n         packets are generated at with a fixed inter-packet\n         injection time specified by sspmSourceFrequency.\n\n         When this attribute is set to 'Poisson', then packets\n         are generated with inter-packet injection times sampled\n         from an exponential distribution with the single\n         distributional parameter determined by the inverse\n         frequency).")
sspmSourceControlFrequency = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 9), SspmMicroSeconds()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlFrequency.setDescription("The inverse of this value is the rate at which packets\n         are generated.  Refer to sspmSourceSamplingDistribution.\n         If the value set is less than the value of\n         sspmGeneralMinFrequency, then the set will fail with an\n         error-status of 'inconsistentValue'.")
sspmSourceControlFirstSeqNum = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 10), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlFirstSeqNum.setDescription('The first sequence number of packets to be transmitted.')
sspmSourceControlLastSeqNum = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 11), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sspmSourceControlLastSeqNum.setDescription('The last sequence number transmitted.  This value is updated\n         by the agent after packet generation.')
sspmSourceControlOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 12), OwnerString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlOwner.setDescription('Name of the management station/application that set\n        up the test.')
sspmSourceControlStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 13), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlStorageType.setDescription("The storage type of this sspmSourceControlEntry.  If the\n        value of this object is 'permanent', no objects in this row\n        need to be writable.")
sspmSourceControlStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 2, 2, 1, 14), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSourceControlStatus.setDescription("Status of this source control entry.\n\n        An entry may not exist in the active state unless all\n        objects in the entry have an appropriate value.\n\n        When this attribute has the value of\n        'active', none of the read-write or read-create attributes\n        in this table may be modified, with the exception of\n        sspmSourceControlEnabled.")
sspmSink = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 28, 1, 5))
sspmSinkTable = MibTable((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1), )
if mibBuilder.loadTexts: sspmSinkTable.setDescription('A table configuring the sink for measurements.')
sspmSinkEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1), ).setIndexNames((0, "SSPM-MIB", "sspmSinkInstance"))
if mibBuilder.loadTexts: sspmSinkEntry.setDescription('The details of a particular sink entry.  If the measurement\n         is a round-trip type, then the sink entry will be on the\n         same probe as the corresponding sspmSourceEntry.  If the\n         measurement is a one-way, type then the sink entry will be\n         on a different probe.')
sspmSinkInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: sspmSinkInstance.setDescription('An index.  When the measurement is for a round-trip\n         measurement, then this table entry is on the same probe as\n         the corresponding sspmSourceEntry, and the value of this\n         attribute should correspond to the value of\n         sspmSourceInstance.  Management applications configuring\n         sinks for one-way measurements could define some\n         scheme whereby the sspmSinkInstance is unique across\n         all probes.  Note that the unique key to this entry is\n         also constructed with sspmSinkType,\n         sspmSinkSourceAddressType, and sspmSinkSourceAddress.\n         To make the implementation simpler, those other\n         attributes are not included in the index but uniqueness\n         is still needed to receive all the packets.')
sspmSinkType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 2), AppLocalIndex()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSinkType.setDescription("The AppLocalIndex value that uniquely identifies the\n         measurement per the APM-MIB.  In order to create a row\n         in this table, there must be a corresponding row in the\n         sspmCapabilitiesTable.  If there is no corresponding\n         row in the sspmCapabilitiestable, then the agent will\n         return an error-status of 'inconsistentValue'.")
sspmSinkSourceAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 3), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSinkSourceAddressType.setDescription('The type of Internet address of the source.')
sspmSinkSourceAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 4), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSinkSourceAddress.setDescription("The Internet address of the source.  The formatting\n        of this object is controlled by the sspmSinkSourceAddressType\n        object above.\n\n        This object should be set only to a valid device address\n        that has been administratively configured into the\n        device.  If a set attempts to set this object to an\n        address that does not belong (i.e., is not administratively\n        configured into the device), the set should fail, and the\n        agent should return a error-status of 'inconsistentValue'.")
sspmSinkExpectedRate = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 5), SspmMicroSeconds()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSinkExpectedRate.setDescription('The expected rate at which packets will arrive.')
sspmSinkEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 6), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSinkEnable.setDescription('Indicates if the sink is enabled or not.')
sspmSinkExpectedFirstSequenceNum = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 7), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSinkExpectedFirstSequenceNum.setDescription('The expected first sequence number of packets.\n         This is used by the sink to determine if packets\n         were lost at the initiation of the test.')
sspmSinkLastSequenceNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 8), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sspmSinkLastSequenceNumber.setDescription('The last sequence number received.')
sspmSinkLastSequenceInvalid = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sspmSinkLastSequenceInvalid.setDescription('The number of packets that arrived whose\n         sequence number was not one plus the value of\n         sspmSinkLastSequenceNumber.')
sspmSinkStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 10), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSinkStorageType.setDescription("The storage type of this sspmSinkEntry.  If the value\n        of this object is 'permanent', no objects in this row\n        need to be writable.")
sspmSinkStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 28, 1, 5, 1, 1, 11), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: sspmSinkStatus.setDescription('Status of this conceptual row.\n         An entry may not exist in the active state unless all\n         objects in the entry have an appropriate value.\n\n         Once this object is set to active(1), no objects with\n         MAX-ACCESS of read-create in the sspmSinkTable can\n         be changed.')
sspmCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 28, 3, 1))
sspmGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 28, 3, 2))
sspmGeneralCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 16, 28, 3, 1, 1)).setObjects(*(("SSPM-MIB", "sspmGeneralGroup"), ("SSPM-MIB", "sspmSourceGroup"), ("SSPM-MIB", "sspmSinkGroup"), ("SSPM-MIB", "sspmUserPassGroup"),))
if mibBuilder.loadTexts: sspmGeneralCompliance.setDescription('A general compliance that allows all things to be optional.')
sspmSourceFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 16, 28, 3, 1, 2)).setObjects(*(("SSPM-MIB", "sspmGeneralGroup"), ("SSPM-MIB", "sspmSourceGroup"), ("SSPM-MIB", "sspmUserPassGroup"),))
if mibBuilder.loadTexts: sspmSourceFullCompliance.setDescription('A source compliance.  Use this compliance when implementing\n     a traffic-source-only device.  This is useful for implementing\n     devices that probe other devices for intrusive application\n     monitoring.  It is also useful for implementing the source\n     of one-way tests used with a sink-only device.')
sspmSinkFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 16, 28, 3, 1, 3)).setObjects(*(("SSPM-MIB", "sspmGeneralGroup"), ("SSPM-MIB", "sspmSinkGroup"),))
if mibBuilder.loadTexts: sspmSinkFullCompliance.setDescription('A sink-only compliance.  Use this compliance when implementing a\n     sink-only device.  This is useful for devices to receive one-way\n     measurements.')
sspmGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 28, 3, 2, 1)).setObjects(*(("SSPM-MIB", "sspmGeneralClockResolution"), ("SSPM-MIB", "sspmGeneralClockMaxSkew"), ("SSPM-MIB", "sspmGeneralClockSource"), ("SSPM-MIB", "sspmGeneralMinFrequency"), ("SSPM-MIB", "sspmCapabilitiesInstance"),))
if mibBuilder.loadTexts: sspmGeneralGroup.setDescription('The objects in the SSPM General Group.')
sspmSourceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 28, 3, 2, 2)).setObjects(*(("SSPM-MIB", "sspmSourceProfileType"), ("SSPM-MIB", "sspmSourceProfilePacketSize"), ("SSPM-MIB", "sspmSourceProfilePacketFillType"), ("SSPM-MIB", "sspmSourceProfilePacketFillValue"), ("SSPM-MIB", "sspmSourceProfileTOS"), ("SSPM-MIB", "sspmSourceProfileFlowLabel"), ("SSPM-MIB", "sspmSourceProfileLooseSrcRteFill"), ("SSPM-MIB", "sspmSourceProfileLooseSrcRteLen"), ("SSPM-MIB", "sspmSourceProfileTTL"), ("SSPM-MIB", "sspmSourceProfileNoFrag"), ("SSPM-MIB", "sspmSourceProfile8021Tagging"), ("SSPM-MIB", "sspmSourceProfileUsername"), ("SSPM-MIB", "sspmSourceProfilePassword"), ("SSPM-MIB", "sspmSourceProfileParameter"), ("SSPM-MIB", "sspmSourceProfileOwner"), ("SSPM-MIB", "sspmSourceProfileStorageType"), ("SSPM-MIB", "sspmSourceProfileStatus"), ("SSPM-MIB", "sspmSourceControlProfile"), ("SSPM-MIB", "sspmSourceControlSrc"), ("SSPM-MIB", "sspmSourceControlDestAddrType"), ("SSPM-MIB", "sspmSourceControlDestAddr"), ("SSPM-MIB", "sspmSourceControlEnabled"), ("SSPM-MIB", "sspmSourceControlTimeOut"), ("SSPM-MIB", "sspmSourceControlSamplingDist"), ("SSPM-MIB", "sspmSourceControlFrequency"), ("SSPM-MIB", "sspmSourceControlFirstSeqNum"), ("SSPM-MIB", "sspmSourceControlLastSeqNum"), ("SSPM-MIB", "sspmSourceControlOwner"), ("SSPM-MIB", "sspmSourceControlStorageType"), ("SSPM-MIB", "sspmSourceControlStatus"),))
if mibBuilder.loadTexts: sspmSourceGroup.setDescription('The objects in the SSPM Source Group.')
sspmUserPassGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 28, 3, 2, 3)).setObjects(*(("SSPM-MIB", "sspmSourceProfileUsername"), ("SSPM-MIB", "sspmSourceProfilePassword"),))
if mibBuilder.loadTexts: sspmUserPassGroup.setDescription('The objects in the SSPM Username and password group.')
sspmSinkGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 28, 3, 2, 4)).setObjects(*(("SSPM-MIB", "sspmSinkType"), ("SSPM-MIB", "sspmSinkSourceAddressType"), ("SSPM-MIB", "sspmSinkSourceAddress"), ("SSPM-MIB", "sspmSinkExpectedRate"), ("SSPM-MIB", "sspmSinkEnable"), ("SSPM-MIB", "sspmSinkExpectedFirstSequenceNum"), ("SSPM-MIB", "sspmSinkLastSequenceNumber"), ("SSPM-MIB", "sspmSinkLastSequenceInvalid"), ("SSPM-MIB", "sspmSinkStorageType"), ("SSPM-MIB", "sspmSinkStatus"),))
if mibBuilder.loadTexts: sspmSinkGroup.setDescription('The objects in the SSPM Sink Group.')
mibBuilder.exportSymbols("SSPM-MIB", sspmSinkSourceAddress=sspmSinkSourceAddress, sspmSourceProfilePacketFillType=sspmSourceProfilePacketFillType, sspmGeneralClockSource=sspmGeneralClockSource, SspmClockSource=SspmClockSource, sspmSourceProfileParameter=sspmSourceProfileParameter, sspmSinkSourceAddressType=sspmSinkSourceAddressType, sspmSourceFullCompliance=sspmSourceFullCompliance, sspmSource=sspmSource, sspmSourceProfilePacketSize=sspmSourceProfilePacketSize, sspmSourceControlDestAddr=sspmSourceControlDestAddr, SspmClockMaxSkew=SspmClockMaxSkew, sspmSourceProfileTTL=sspmSourceProfileTTL, sspmSourceProfileOwner=sspmSourceProfileOwner, sspmGeneralMinFrequency=sspmGeneralMinFrequency, sspmSourceProfileEntry=sspmSourceProfileEntry, sspmMIB=sspmMIB, sspmSink=sspmSink, sspmSourceControlLastSeqNum=sspmSourceControlLastSeqNum, sspmCapabilitiesTable=sspmCapabilitiesTable, sspmMIBConformance=sspmMIBConformance, sspmSourceControlSamplingDist=sspmSourceControlSamplingDist, sspmSourceControlStatus=sspmSourceControlStatus, sspmMIBNotifications=sspmMIBNotifications, sspmSinkEnable=sspmSinkEnable, sspmCapabilitiesInstance=sspmCapabilitiesInstance, SspmMicroSeconds=SspmMicroSeconds, sspmSourceProfileFlowLabel=sspmSourceProfileFlowLabel, sspmSourceControlProfile=sspmSourceControlProfile, sspmSourceControlOwner=sspmSourceControlOwner, sspmGeneral=sspmGeneral, sspmSourceProfilePacketFillValue=sspmSourceProfilePacketFillValue, sspmSourceProfileStorageType=sspmSourceProfileStorageType, sspmSinkType=sspmSinkType, sspmSinkInstance=sspmSinkInstance, sspmGeneralCompliance=sspmGeneralCompliance, sspmSourceControlEnabled=sspmSourceControlEnabled, sspmSinkExpectedFirstSequenceNum=sspmSinkExpectedFirstSequenceNum, sspmSourceProfileInstance=sspmSourceProfileInstance, sspmCompliances=sspmCompliances, sspmSinkEntry=sspmSinkEntry, sspmSourceProfileType=sspmSourceProfileType, sspmSourceControlStorageType=sspmSourceControlStorageType, sspmSinkFullCompliance=sspmSinkFullCompliance, sspmSourceControlInstance=sspmSourceControlInstance, sspmSourceProfileLooseSrcRteLen=sspmSourceProfileLooseSrcRteLen, sspmSourceProfileTable=sspmSourceProfileTable, sspmGeneralClockMaxSkew=sspmGeneralClockMaxSkew, sspmSourceControlTable=sspmSourceControlTable, sspmMIBObjects=sspmMIBObjects, sspmGeneralGroup=sspmGeneralGroup, sspmCapabilitiesEntry=sspmCapabilitiesEntry, sspmGroups=sspmGroups, sspmUserPassGroup=sspmUserPassGroup, sspmSourceControlDestAddrType=sspmSourceControlDestAddrType, sspmSourceControlEntry=sspmSourceControlEntry, sspmSourceProfileTOS=sspmSourceProfileTOS, sspmSinkTable=sspmSinkTable, sspmSinkStatus=sspmSinkStatus, sspmSinkLastSequenceNumber=sspmSinkLastSequenceNumber, PYSNMP_MODULE_ID=sspmMIB, sspmSourceProfilePassword=sspmSourceProfilePassword, sspmSinkLastSequenceInvalid=sspmSinkLastSequenceInvalid, sspmGeneralClockResolution=sspmGeneralClockResolution, sspmSourceProfileUsername=sspmSourceProfileUsername, sspmSourceControlTimeOut=sspmSourceControlTimeOut, sspmSourceControlFirstSeqNum=sspmSourceControlFirstSeqNum, sspmSourceProfile8021Tagging=sspmSourceProfile8021Tagging, sspmSinkExpectedRate=sspmSinkExpectedRate, sspmSourceControlFrequency=sspmSourceControlFrequency, sspmSinkGroup=sspmSinkGroup, sspmSourceGroup=sspmSourceGroup, sspmSourceControlSrc=sspmSourceControlSrc, sspmSourceProfileLooseSrcRteFill=sspmSourceProfileLooseSrcRteFill, sspmSourceProfileStatus=sspmSourceProfileStatus, sspmSourceProfileNoFrag=sspmSourceProfileNoFrag, sspmSinkStorageType=sspmSinkStorageType)



#
# PySNMP MIB module BGP4-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/BGP4-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:06:31 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ConstraintsIntersection, ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, IpAddress, Counter32, Unsigned32, Bits, Gauge32, Integer32, ModuleIdentity, MibIdentifier, mib_2, TimeTicks, ObjectIdentity, iso, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "IpAddress", "Counter32", "Unsigned32", "Bits", "Gauge32", "Integer32", "ModuleIdentity", "MibIdentifier", "mib-2", "TimeTicks", "ObjectIdentity", "iso", "NotificationType")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
bgp = ModuleIdentity((1, 3, 6, 1, 2, 1, 15)).setRevisions(("2006-01-11 00:00", "1994-05-05 00:00", "1991-10-26 18:39",))
if mibBuilder.loadTexts: bgp.setLastUpdated('200601110000Z')
if mibBuilder.loadTexts: bgp.setOrganization('IETF IDR Working Group')
if mibBuilder.loadTexts: bgp.setContactInfo('E-mail:  idr@ietf.org\n\n                          Jeffrey Haas, Susan Hares  (Editors)\n                          NextHop Technologies\n                          825 Victors Way\n                          Suite 100\n                          Ann Arbor, MI 48108-2738\n                          Tel: +1 734 222-1600\n                          Fax: +1 734 222-1602\n                          E-mail: jhaas@nexthop.com\n                                  skh@nexthop.com')
if mibBuilder.loadTexts: bgp.setDescription('The MIB module for the BGP-4 protocol.\n\n                     Copyright (C) The Internet Society (2006).  This\n                     version of this MIB module is part of RFC 4273;\n                     see the RFC itself for full legal notices.')
bgpVersion = MibScalar((1, 3, 6, 1, 2, 1, 15, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpVersion.setDescription('Vector of supported BGP protocol version\n                     numbers.  Each peer negotiates the version\n                     from this vector.  Versions are identified\n                     via the string of bits contained within this\n                     object.  The first octet contains bits 0 to\n                     7, the second octet contains bits 8 to 15,\n                     and so on, with the most significant bit\n                     referring to the lowest bit number in the\n                     octet (e.g., the MSB of the first octet\n                     refers to bit 0).  If a bit, i, is present\n                     and set, then the version (i+1) of the BGP\n                     is supported.')
bgpLocalAs = MibScalar((1, 3, 6, 1, 2, 1, 15, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpLocalAs.setDescription('The local autonomous system number.')
bgpPeerTable = MibTable((1, 3, 6, 1, 2, 1, 15, 3), )
if mibBuilder.loadTexts: bgpPeerTable.setDescription('BGP peer table.  This table contains,\n                     one entry per BGP peer, information about the\n                     connections with BGP peers.')
bgpPeerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 15, 3, 1), ).setIndexNames((0, "BGP4-MIB", "bgpPeerRemoteAddr"))
if mibBuilder.loadTexts: bgpPeerEntry.setDescription('Entry containing information about the\n                     connection with a BGP peer.')
bgpPeerIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerIdentifier.setDescription("The BGP Identifier of this entry's BGP peer.\n                     This entry MUST be 0.0.0.0 unless the\n                     bgpPeerState is in the openconfirm or the\n                     established state.")
bgpPeerState = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("idle", 1), ("connect", 2), ("active", 3), ("opensent", 4), ("openconfirm", 5), ("established", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerState.setDescription('The BGP peer connection state.')
bgpPeerAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("stop", 1), ("start", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: bgpPeerAdminStatus.setDescription("The desired state of the BGP connection.\n                     A transition from 'stop' to 'start' will cause\n                     the BGP Manual Start Event to be generated.\n                     A transition from 'start' to 'stop' will cause\n                     the BGP Manual Stop Event to be generated.\n                     This parameter can be used to restart BGP peer\n                     connections.  Care should be used in providing\n                     write access to this object without adequate\n                     authentication.")
bgpPeerNegotiatedVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerNegotiatedVersion.setDescription('The negotiated version of BGP running between\n                     the two peers.\n\n                     This entry MUST be zero (0) unless the\n                     bgpPeerState is in the openconfirm or the\n                     established state.\n\n                     Note that legal values for this object are\n                     between 0 and 255.')
bgpPeerLocalAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 5), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerLocalAddr.setDescription("The local IP address of this entry's BGP\n                     connection.")
bgpPeerLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerLocalPort.setDescription('The local port for the TCP connection between\n                     the BGP peers.')
bgpPeerRemoteAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 7), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerRemoteAddr.setDescription("The remote IP address of this entry's BGP\n                     peer.")
bgpPeerRemotePort = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerRemotePort.setDescription('The remote port for the TCP connection\n                     between the BGP peers.  Note that the\n                     objects bgpPeerLocalAddr,\n                     bgpPeerLocalPort, bgpPeerRemoteAddr, and\n                     bgpPeerRemotePort provide the appropriate\n                     reference to the standard MIB TCP\n                     connection table.')
bgpPeerRemoteAs = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerRemoteAs.setDescription('The remote autonomous system number received in\n                     the BGP OPEN message.')
bgpPeerInUpdates = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerInUpdates.setDescription('The number of BGP UPDATE messages\n                     received on this connection.')
bgpPeerOutUpdates = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerOutUpdates.setDescription('The number of BGP UPDATE messages\n                     transmitted on this connection.')
bgpPeerInTotalMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerInTotalMessages.setDescription('The total number of messages received\n                     from the remote peer on this connection.')
bgpPeerOutTotalMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerOutTotalMessages.setDescription('The total number of messages transmitted to\n                     the remote peer on this connection.')
bgpPeerLastError = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 14), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,2)).setFixedLength(2)).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerLastError.setDescription('The last error code and subcode seen by this\n                     peer on this connection.  If no error has\n                     occurred, this field is zero.  Otherwise, the\n                     first byte of this two byte OCTET STRING\n                     contains the error code, and the second byte\n                     contains the subcode.')
bgpPeerFsmEstablishedTransitions = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerFsmEstablishedTransitions.setDescription('The total number of times the BGP FSM\n                     transitioned into the established state\n                     for this peer.')
bgpPeerFsmEstablishedTime = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 16), Gauge32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerFsmEstablishedTime.setDescription('This timer indicates how long (in\n                     seconds) this peer has been in the\n                     established state or how long\n                     since this peer was last in the\n                     established state.  It is set to zero when\n                     a new peer is configured or when the router is\n                     booted.')
bgpPeerConnectRetryInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 17), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: bgpPeerConnectRetryInterval.setDescription('Time interval (in seconds) for the\n                     ConnectRetry timer.  The suggested value\n                     for this timer is 120 seconds.')
bgpPeerHoldTime = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 18), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(3,65535),))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerHoldTime.setDescription('Time interval (in seconds) for the Hold\n                     Timer established with the peer.  The\n                     value of this object is calculated by this\n                     BGP speaker, using the smaller of the\n                     values in bgpPeerHoldTimeConfigured and the\n                     Hold Time received in the OPEN message.\n\n                     This value must be at least three seconds\n                     if it is not zero (0).\n\n                     If the Hold Timer has not been established\n                     with the peer this object MUST have a value\n                     of zero (0).\n\n                     If the bgpPeerHoldTimeConfigured object has\n                     a value of (0), then this object MUST have a\n                     value of (0).')
bgpPeerKeepAlive = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 19), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(1,21845),))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerKeepAlive.setDescription('Time interval (in seconds) for the KeepAlive\n                     timer established with the peer.  The value\n                     of this object is calculated by this BGP\n                     speaker such that, when compared with\n                     bgpPeerHoldTime, it has the same proportion\n                     that bgpPeerKeepAliveConfigured has,\n                     compared with bgpPeerHoldTimeConfigured.\n\n                     If the KeepAlive timer has not been established\n                     with the peer, this object MUST have a value\n                     of zero (0).\n\n                     If the of bgpPeerKeepAliveConfigured object\n                     has a value of (0), then this object MUST have\n                     a value of (0).')
bgpPeerHoldTimeConfigured = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 20), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(3,65535),))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: bgpPeerHoldTimeConfigured.setDescription('Time interval (in seconds) for the Hold Time\n                     configured for this BGP speaker with this\n                     peer.  This value is placed in an OPEN\n                     message sent to this peer by this BGP\n                     speaker, and is compared with the Hold\n                     Time field in an OPEN message received\n                     from the peer when determining the Hold\n                     Time (bgpPeerHoldTime) with the peer.\n                     This value must not be less than three\n                     seconds if it is not zero (0).  If it is\n                     zero (0), the Hold Time is NOT to be\n                     established with the peer.  The suggested\n                     value for this timer is 90 seconds.')
bgpPeerKeepAliveConfigured = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 21), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(1,21845),))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: bgpPeerKeepAliveConfigured.setDescription("Time interval (in seconds) for the\n                     KeepAlive timer configured for this BGP\n                     speaker with this peer.  The value of this\n                     object will only determine the\n                     KEEPALIVE messages' frequency relative to\n                     the value specified in\n                     bgpPeerHoldTimeConfigured; the actual\n                     time interval for the KEEPALIVE messages is\n                     indicated by bgpPeerKeepAlive.  A\n                     reasonable maximum value for this timer\n                     would be one third of that of\n                     bgpPeerHoldTimeConfigured.\n                     If the value of this object is zero (0),\n                     no periodical KEEPALIVE messages are sent\n                     to the peer after the BGP connection has\n                     been established.  The suggested value for\n                     this timer is 30 seconds.")
bgpPeerMinASOriginationInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 22), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: bgpPeerMinASOriginationInterval.setDescription('Time interval (in seconds) for the\n                     MinASOriginationInterval timer.\n                     The suggested value for this timer is 15\n                     seconds.')
bgpPeerMinRouteAdvertisementInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 23), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: bgpPeerMinRouteAdvertisementInterval.setDescription('Time interval (in seconds) for the\n                     MinRouteAdvertisementInterval timer.\n                     The suggested value for this timer is 30\n                     seconds for EBGP connections and 5\n                     seconds for IBGP connections.')
bgpPeerInUpdateElapsedTime = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 3, 1, 24), Gauge32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPeerInUpdateElapsedTime.setDescription('Elapsed time (in seconds) since the last BGP\n                     UPDATE message was received from the peer.\n                     Each time bgpPeerInUpdates is incremented,\n                     the value of this object is set to zero (0).')
bgpIdentifier = MibScalar((1, 3, 6, 1, 2, 1, 15, 4), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpIdentifier.setDescription('The BGP Identifier of the local system.')
bgpRcvdPathAttrTable = MibTable((1, 3, 6, 1, 2, 1, 15, 5), )
if mibBuilder.loadTexts: bgpRcvdPathAttrTable.setDescription('The BGP Received Path Attribute Table\n                     contains information about paths to\n                     destination networks, received from all\n                     peers running BGP version 3 or less.')
bgpPathAttrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 15, 5, 1), ).setIndexNames((0, "BGP4-MIB", "bgpPathAttrDestNetwork"), (0, "BGP4-MIB", "bgpPathAttrPeer"))
if mibBuilder.loadTexts: bgpPathAttrEntry.setDescription('Information about a path to a network.')
bgpPathAttrPeer = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 5, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPathAttrPeer.setDescription('The IP address of the peer where the path\n                     information was learned.')
bgpPathAttrDestNetwork = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 5, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPathAttrDestNetwork.setDescription('The address of the destination network.')
bgpPathAttrOrigin = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 5, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("igp", 1), ("egp", 2), ("incomplete", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPathAttrOrigin.setDescription('The ultimate origin of the path information.')
bgpPathAttrASPath = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 5, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPathAttrASPath.setDescription('The set of ASes that must be traversed to reach\n                     the network.  This object is probably best\n                     represented as SEQUENCE OF INTEGER.  For SMI\n                     compatibility, though, it is represented as\n                     OCTET STRING.  Each AS is represented as a pair\n                     of octets according to the following algorithm:\n\n                        first-byte-of-pair = ASNumber / 256;\n                        second-byte-of-pair = ASNumber & 255;')
bgpPathAttrNextHop = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 5, 1, 5), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPathAttrNextHop.setDescription('The address of the border router that should\n                     be used for the destination network.')
bgpPathAttrInterASMetric = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 5, 1, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgpPathAttrInterASMetric.setDescription('The optional inter-AS metric.  If this\n                     attribute has not been provided for this route,\n                     the value for this object is 0.')
bgp4PathAttrTable = MibTable((1, 3, 6, 1, 2, 1, 15, 6), )
if mibBuilder.loadTexts: bgp4PathAttrTable.setDescription('The BGP-4 Received Path Attribute Table\n                     contains information about paths to\n                     destination networks, received from all\n                     BGP4 peers.')
bgp4PathAttrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 15, 6, 1), ).setIndexNames((0, "BGP4-MIB", "bgp4PathAttrIpAddrPrefix"), (0, "BGP4-MIB", "bgp4PathAttrIpAddrPrefixLen"), (0, "BGP4-MIB", "bgp4PathAttrPeer"))
if mibBuilder.loadTexts: bgp4PathAttrEntry.setDescription('Information about a path to a network.')
bgp4PathAttrPeer = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrPeer.setDescription('The IP address of the peer where the path\n                     information was learned.')
bgp4PathAttrIpAddrPrefixLen = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,32))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrIpAddrPrefixLen.setDescription('Length in bits of the IP address prefix in\n                     the Network Layer Reachability\n                     Information field.')
bgp4PathAttrIpAddrPrefix = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 3), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrIpAddrPrefix.setDescription('An IP address prefix in the Network Layer\n                     Reachability Information field.  This object\n                     is an IP address containing the prefix with\n                     length specified by\n                     bgp4PathAttrIpAddrPrefixLen.\n                     Any bits beyond the length specified by\n                     bgp4PathAttrIpAddrPrefixLen are zeroed.')
bgp4PathAttrOrigin = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("igp", 1), ("egp", 2), ("incomplete", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrOrigin.setDescription('The ultimate origin of the path\n                     information.')
bgp4PathAttrASPathSegment = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrASPathSegment.setDescription('The sequence of AS path segments.  Each AS\n                     path segment is represented by a triple\n                     <type, length, value>.\n\n                     The type is a 1-octet field that has two\n                     possible values:\n                         1      AS_SET: unordered set of ASes that a\n                                     route in the UPDATE message\n                                     has traversed\n\n                         2      AS_SEQUENCE: ordered set of ASes that\n                                     a route in the UPDATE message\n                                     has traversed.\n\n                     The length is a 1-octet field containing the\n                     number of ASes in the value field.\n\n                     The value field contains one or more AS\n                     numbers.  Each AS is represented in the octet\n                     string as a pair of octets according to the\n                     following algorithm:\n\n                        first-byte-of-pair = ASNumber / 256;\n                        second-byte-of-pair = ASNumber & 255;\n\n                     Known Issues:\n                     o BGP Confederations will result in\n                       a type of either 3 or 4.\n                     o An AS Path may be longer than 255 octets.\n                       This may result in this object containing\n                       a truncated AS Path.')
bgp4PathAttrNextHop = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 6), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrNextHop.setDescription('The address of the border router that\n                     should be used for the destination\n                     network.  This address is the NEXT_HOP\n                     address received in the UPDATE packet.')
bgp4PathAttrMultiExitDisc = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrMultiExitDisc.setDescription('This metric is used to discriminate\n                     between multiple exit points to an\n                     adjacent autonomous system.  A value of -1\n                     indicates the absence of this attribute.\n\n                     Known Issues:\n                     o The BGP-4 specification uses an\n                       unsigned 32 bit number.  Thus, this\n                       object cannot represent the full\n                       range of the protocol.')
bgp4PathAttrLocalPref = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrLocalPref.setDescription("The originating BGP4 speaker's degree of\n                     preference for an advertised route.  A\n                     value of -1 indicates the absence of this\n                     attribute.\n\n                     Known Issues:\n                     o The BGP-4 specification uses an\n                       unsigned 32 bit number and thus this\n                       object cannot represent the full\n                       range of the protocol.")
bgp4PathAttrAtomicAggregate = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 9), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("lessSpecificRouteNotSelected", 1), ("lessSpecificRouteSelected", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrAtomicAggregate.setDescription("If the ATOMIC_AGGREGATE attribute is present\n                     in the Path Attributes then this object MUST\n                     have a value of 'lessSpecificRouteNotSelected'.\n\n                     If the ATOMIC_AGGREGATE attribute is missing\n                     in the Path Attributes then this object MUST\n                     have a value of 'lessSpecificRouteSelected'.\n\n                     Note that ATOMIC_AGGREGATE is now a primarily\n                     informational attribute.")
bgp4PathAttrAggregatorAS = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrAggregatorAS.setDescription('The AS number of the last BGP4 speaker that\n                     performed route aggregation.  A value of\n                     zero (0) indicates the absence of this\n                     attribute.\n\n                     Note that propagation of AS of zero is illegal\n                     in the Internet.')
bgp4PathAttrAggregatorAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 11), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrAggregatorAddr.setDescription('The IP address of the last BGP4 speaker\n                     that performed route aggregation.  A\n                     value of 0.0.0.0 indicates the absence\n                     of this attribute.')
bgp4PathAttrCalcLocalPref = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrCalcLocalPref.setDescription('The degree of preference calculated by the\n                     receiving BGP4 speaker for an advertised\n                     route.  A value of -1 indicates the\n                     absence of this attribute.\n\n                     Known Issues:\n                     o The BGP-4 specification uses an\n                       unsigned 32 bit number and thus this\n                       object cannot represent the full\n                       range of the protocol.')
bgp4PathAttrBest = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrBest.setDescription('An indication of whether this route\n                     was chosen as the best BGP4 route for this\n                     destination.')
bgp4PathAttrUnknown = MibTableColumn((1, 3, 6, 1, 2, 1, 15, 6, 1, 14), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: bgp4PathAttrUnknown.setDescription('One or more path attributes not understood by\n                     this BGP4 speaker.\n\n                     Path attributes are recorded in the Update Path\n                     attribute format of type, length, value.\n\n                     Size zero (0) indicates the absence of such\n                     attributes.\n\n                     Octets beyond the maximum size, if any, are not\n                     recorded by this object.\n\n                     Known Issues:\n                     o Attributes understood by this speaker, but not\n                       represented in this MIB, are unavailable to\n                       the agent.')
bgpNotification = MibIdentifier((1, 3, 6, 1, 2, 1, 15, 0))
bgpEstablishedNotification = NotificationType((1, 3, 6, 1, 2, 1, 15, 0, 1)).setObjects(*(("BGP4-MIB", "bgpPeerRemoteAddr"), ("BGP4-MIB", "bgpPeerLastError"), ("BGP4-MIB", "bgpPeerState"),))
if mibBuilder.loadTexts: bgpEstablishedNotification.setDescription('The bgpEstablishedNotification event is generated\n                     when the BGP FSM enters the established state.\n\n                     This Notification replaces the bgpEstablished\n                     Notification.')
bgpBackwardTransNotification = NotificationType((1, 3, 6, 1, 2, 1, 15, 0, 2)).setObjects(*(("BGP4-MIB", "bgpPeerRemoteAddr"), ("BGP4-MIB", "bgpPeerLastError"), ("BGP4-MIB", "bgpPeerState"),))
if mibBuilder.loadTexts: bgpBackwardTransNotification.setDescription('The bgpBackwardTransNotification event is\n                     generated when the BGP FSM moves from a higher\n                     numbered state to a lower numbered state.\n\n                     This Notification replaces the\n                     bgpBackwardsTransition Notification.')
bgpTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 15, 7))
bgpEstablished = NotificationType((1, 3, 6, 1, 2, 1, 15, 7, 1)).setObjects(*(("BGP4-MIB", "bgpPeerLastError"), ("BGP4-MIB", "bgpPeerState"),))
if mibBuilder.loadTexts: bgpEstablished.setDescription('The bgpEstablished event is generated when\n                     the BGP FSM enters the established state.\n\n                     This Notification has been replaced by the\n                     bgpEstablishedNotification Notification.')
bgpBackwardTransition = NotificationType((1, 3, 6, 1, 2, 1, 15, 7, 2)).setObjects(*(("BGP4-MIB", "bgpPeerLastError"), ("BGP4-MIB", "bgpPeerState"),))
if mibBuilder.loadTexts: bgpBackwardTransition.setDescription('The bgpBackwardTransition event is generated\n                     when the BGP FSM moves from a higher numbered\n                     state to a lower numbered state.\n\n                     This Notification has been replaced by the\n                     bgpBackwardTransNotification Notification.')
bgp4MIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 15, 8))
bgp4MIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 15, 8, 1))
bgp4MIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 15, 8, 2))
bgp4MIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 15, 8, 1, 1)).setObjects(*(("BGP4-MIB", "bgp4MIBGlobalsGroup"), ("BGP4-MIB", "bgp4MIBPeerGroup"), ("BGP4-MIB", "bgp4MIBPathAttrGroup"), ("BGP4-MIB", "bgp4MIBNotificationGroup"),))
if mibBuilder.loadTexts: bgp4MIBCompliance.setDescription('The compliance statement for entities which\n                     implement the BGP4 mib.')
bgp4MIBDeprecatedCompliances = ModuleCompliance((1, 3, 6, 1, 2, 1, 15, 8, 1, 2)).setObjects(*(("BGP4-MIB", "bgp4MIBTrapGroup"),))
if mibBuilder.loadTexts: bgp4MIBDeprecatedCompliances.setDescription('The compliance statement documenting deprecated\n                     objects in the BGP4 mib.')
bgp4MIBObsoleteCompliances = ModuleCompliance((1, 3, 6, 1, 2, 1, 15, 8, 1, 3)).setObjects(*(("BGP4-MIB", "bgpRcvdPathAttrGroup"),))
if mibBuilder.loadTexts: bgp4MIBObsoleteCompliances.setDescription('The compliance statement documenting obsolete\n                     objects in the BGP4 mib.')
bgp4MIBGlobalsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 15, 8, 2, 1)).setObjects(*(("BGP4-MIB", "bgpVersion"), ("BGP4-MIB", "bgpLocalAs"), ("BGP4-MIB", "bgpIdentifier"),))
if mibBuilder.loadTexts: bgp4MIBGlobalsGroup.setDescription('A collection of objects providing\n                     information on global BGP state.')
bgp4MIBPeerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 15, 8, 2, 2)).setObjects(*(("BGP4-MIB", "bgpPeerIdentifier"), ("BGP4-MIB", "bgpPeerState"), ("BGP4-MIB", "bgpPeerAdminStatus"), ("BGP4-MIB", "bgpPeerNegotiatedVersion"), ("BGP4-MIB", "bgpPeerLocalAddr"), ("BGP4-MIB", "bgpPeerLocalPort"), ("BGP4-MIB", "bgpPeerRemoteAddr"), ("BGP4-MIB", "bgpPeerRemotePort"), ("BGP4-MIB", "bgpPeerRemoteAs"), ("BGP4-MIB", "bgpPeerInUpdates"), ("BGP4-MIB", "bgpPeerOutUpdates"), ("BGP4-MIB", "bgpPeerInTotalMessages"), ("BGP4-MIB", "bgpPeerOutTotalMessages"), ("BGP4-MIB", "bgpPeerLastError"), ("BGP4-MIB", "bgpPeerFsmEstablishedTransitions"), ("BGP4-MIB", "bgpPeerFsmEstablishedTime"), ("BGP4-MIB", "bgpPeerConnectRetryInterval"), ("BGP4-MIB", "bgpPeerHoldTime"), ("BGP4-MIB", "bgpPeerKeepAlive"), ("BGP4-MIB", "bgpPeerHoldTimeConfigured"), ("BGP4-MIB", "bgpPeerKeepAliveConfigured"), ("BGP4-MIB", "bgpPeerMinASOriginationInterval"), ("BGP4-MIB", "bgpPeerMinRouteAdvertisementInterval"), ("BGP4-MIB", "bgpPeerInUpdateElapsedTime"),))
if mibBuilder.loadTexts: bgp4MIBPeerGroup.setDescription('A collection of objects for managing\n                     BGP peers.')
bgpRcvdPathAttrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 15, 8, 2, 3)).setObjects(*(("BGP4-MIB", "bgpPathAttrPeer"), ("BGP4-MIB", "bgpPathAttrDestNetwork"), ("BGP4-MIB", "bgpPathAttrOrigin"), ("BGP4-MIB", "bgpPathAttrASPath"), ("BGP4-MIB", "bgpPathAttrNextHop"), ("BGP4-MIB", "bgpPathAttrInterASMetric"),))
if mibBuilder.loadTexts: bgpRcvdPathAttrGroup.setDescription('A collection of objects for managing BGP-3 and\n                    earlier path entries.\n\n                    This conformance group, like BGP-3, is obsolete.')
bgp4MIBPathAttrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 15, 8, 2, 4)).setObjects(*(("BGP4-MIB", "bgp4PathAttrPeer"), ("BGP4-MIB", "bgp4PathAttrIpAddrPrefixLen"), ("BGP4-MIB", "bgp4PathAttrIpAddrPrefix"), ("BGP4-MIB", "bgp4PathAttrOrigin"), ("BGP4-MIB", "bgp4PathAttrASPathSegment"), ("BGP4-MIB", "bgp4PathAttrNextHop"), ("BGP4-MIB", "bgp4PathAttrMultiExitDisc"), ("BGP4-MIB", "bgp4PathAttrLocalPref"), ("BGP4-MIB", "bgp4PathAttrAtomicAggregate"), ("BGP4-MIB", "bgp4PathAttrAggregatorAS"), ("BGP4-MIB", "bgp4PathAttrAggregatorAddr"), ("BGP4-MIB", "bgp4PathAttrCalcLocalPref"), ("BGP4-MIB", "bgp4PathAttrBest"), ("BGP4-MIB", "bgp4PathAttrUnknown"),))
if mibBuilder.loadTexts: bgp4MIBPathAttrGroup.setDescription('A collection of objects for managing\n                     BGP path entries.')
bgp4MIBTrapGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 15, 8, 2, 5)).setObjects(*(("BGP4-MIB", "bgpEstablished"), ("BGP4-MIB", "bgpBackwardTransition"),))
if mibBuilder.loadTexts: bgp4MIBTrapGroup.setDescription('A collection of notifications for signaling\n                     changes in BGP peer relationships.\n\n                     Obsoleted by bgp4MIBNotificationGroup')
bgp4MIBNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 15, 8, 2, 6)).setObjects(*(("BGP4-MIB", "bgpEstablishedNotification"), ("BGP4-MIB", "bgpBackwardTransNotification"),))
if mibBuilder.loadTexts: bgp4MIBNotificationGroup.setDescription('A collection of notifications for signaling\n                     changes in BGP peer relationships.\n\n                     Obsoletes bgp4MIBTrapGroup.')
mibBuilder.exportSymbols("BGP4-MIB", bgpTraps=bgpTraps, bgp4PathAttrASPathSegment=bgp4PathAttrASPathSegment, bgpPeerLocalAddr=bgpPeerLocalAddr, bgp4MIBGlobalsGroup=bgp4MIBGlobalsGroup, bgpNotification=bgpNotification, bgpEstablished=bgpEstablished, bgp=bgp, bgpPeerRemoteAs=bgpPeerRemoteAs, bgpPeerMinASOriginationInterval=bgpPeerMinASOriginationInterval, bgp4PathAttrBest=bgp4PathAttrBest, bgpPathAttrEntry=bgpPathAttrEntry, bgpPeerLocalPort=bgpPeerLocalPort, bgpPeerFsmEstablishedTransitions=bgpPeerFsmEstablishedTransitions, bgpPeerLastError=bgpPeerLastError, bgpPeerInUpdates=bgpPeerInUpdates, bgpPeerKeepAlive=bgpPeerKeepAlive, bgpPeerInTotalMessages=bgpPeerInTotalMessages, bgpPeerRemotePort=bgpPeerRemotePort, bgpVersion=bgpVersion, bgp4PathAttrIpAddrPrefix=bgp4PathAttrIpAddrPrefix, bgpPeerTable=bgpPeerTable, bgpPeerHoldTimeConfigured=bgpPeerHoldTimeConfigured, bgpPathAttrDestNetwork=bgpPathAttrDestNetwork, bgp4PathAttrCalcLocalPref=bgp4PathAttrCalcLocalPref, bgpBackwardTransition=bgpBackwardTransition, bgpPeerFsmEstablishedTime=bgpPeerFsmEstablishedTime, bgp4MIBCompliance=bgp4MIBCompliance, bgpPeerOutTotalMessages=bgpPeerOutTotalMessages, bgp4PathAttrIpAddrPrefixLen=bgp4PathAttrIpAddrPrefixLen, bgpPeerEntry=bgpPeerEntry, bgp4PathAttrOrigin=bgp4PathAttrOrigin, bgp4MIBCompliances=bgp4MIBCompliances, bgp4PathAttrLocalPref=bgp4PathAttrLocalPref, bgp4MIBDeprecatedCompliances=bgp4MIBDeprecatedCompliances, bgp4PathAttrUnknown=bgp4PathAttrUnknown, bgpLocalAs=bgpLocalAs, bgpPathAttrNextHop=bgpPathAttrNextHop, bgp4MIBPeerGroup=bgp4MIBPeerGroup, bgpPathAttrASPath=bgpPathAttrASPath, bgpPeerNegotiatedVersion=bgpPeerNegotiatedVersion, bgp4PathAttrNextHop=bgp4PathAttrNextHop, bgpPeerState=bgpPeerState, bgpRcvdPathAttrGroup=bgpRcvdPathAttrGroup, bgp4MIBObsoleteCompliances=bgp4MIBObsoleteCompliances, bgpRcvdPathAttrTable=bgpRcvdPathAttrTable, bgp4PathAttrAggregatorAddr=bgp4PathAttrAggregatorAddr, bgpPeerInUpdateElapsedTime=bgpPeerInUpdateElapsedTime, bgpPeerRemoteAddr=bgpPeerRemoteAddr, bgp4PathAttrTable=bgp4PathAttrTable, bgp4MIBPathAttrGroup=bgp4MIBPathAttrGroup, bgpPeerOutUpdates=bgpPeerOutUpdates, bgpPeerMinRouteAdvertisementInterval=bgpPeerMinRouteAdvertisementInterval, bgpPathAttrInterASMetric=bgpPathAttrInterASMetric, bgpPeerKeepAliveConfigured=bgpPeerKeepAliveConfigured, bgpPeerConnectRetryInterval=bgpPeerConnectRetryInterval, bgp4PathAttrMultiExitDisc=bgp4PathAttrMultiExitDisc, bgp4MIBNotificationGroup=bgp4MIBNotificationGroup, bgp4MIBConformance=bgp4MIBConformance, bgpPathAttrPeer=bgpPathAttrPeer, bgp4PathAttrEntry=bgp4PathAttrEntry, bgpPathAttrOrigin=bgpPathAttrOrigin, bgp4MIBTrapGroup=bgp4MIBTrapGroup, bgpBackwardTransNotification=bgpBackwardTransNotification, PYSNMP_MODULE_ID=bgp, bgpPeerIdentifier=bgpPeerIdentifier, bgpIdentifier=bgpIdentifier, bgp4PathAttrAggregatorAS=bgp4PathAttrAggregatorAS, bgp4PathAttrPeer=bgp4PathAttrPeer, bgpEstablishedNotification=bgpEstablishedNotification, bgp4MIBGroups=bgp4MIBGroups, bgp4PathAttrAtomicAggregate=bgp4PathAttrAtomicAggregate, bgpPeerHoldTime=bgpPeerHoldTime, bgpPeerAdminStatus=bgpPeerAdminStatus)
